summaryrefslogtreecommitdiff
path: root/src/mmo/enums.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mmo/enums.hpp')
-rw-r--r--src/mmo/enums.hpp25
1 files changed, 7 insertions, 18 deletions
diff --git a/src/mmo/enums.hpp b/src/mmo/enums.hpp
index bf8a75c..caecc13 100644
--- a/src/mmo/enums.hpp
+++ b/src/mmo/enums.hpp
@@ -66,14 +66,14 @@ enum class SkillFlags : uint16_t;
}
using e::SkillFlags;
// Option and Opt1..3 in map.hpp
namespace e
{
-enum class Option : uint16_t;
-constexpr Option get_enum_min_value(Option) { return Option(0x0000); }
-constexpr Option get_enum_max_value(Option) { return Option(0xffff); }
+enum class Opt0 : uint16_t;
+constexpr Opt0 get_enum_min_value(Opt0) { return Opt0(0x0000); }
+constexpr Opt0 get_enum_max_value(Opt0) { return Opt0(0xffff); }
}
-using e::Option;
+using e::Opt0;
enum class ATTR
{
@@ -101,22 +101,10 @@ enum class ItemLook : uint16_t
{
NONE = 0,
BLADE = 1, // or some other common weapons
- _2,
SETZER_AND_SCYTHE = 3,
- _6,
STAFF = 10,
BOW = 11,
- _13 = 13,
- _14 = 14,
- _16 = 16,
- SINGLE_HANDED_COUNT = 17,
-
- DUAL_BLADE = 0x11,
- DUAL_2 = 0x12,
- DUAL_6 = 0x13,
- DUAL_12 = 0x14,
- DUAL_16 = 0x15,
- DUAL_26 = 0x16,
+ COUNT = 17,
};
enum class SEX : uint8_t
@@ -124,6 +112,7 @@ enum class SEX : uint8_t
FEMALE = 0,
MALE = 1,
// For items. This is also used as error, sometime.
+ // TODO switch to Option<SEX> where appropriate.
NEUTRAL = 2,
};
inline
@@ -66,14 +66,14 @@ enum class SkillFlags : uint16_t;
}
using e::SkillFlags;
-// Option and Opt1..3 in map.hpp
+// Opt0 and Opt1..3 in map.hpp
namespace e
{